# CONCISE (CONCatenatIon SErvice)

[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=podaac_concise&metric=coverage)](https://sonarcloud.io/dashboard?id=podaac_concise)  
develop: [![Develop Build](https://github.com/podaac/concise/actions/workflows/build-pipeline.yml/badge.svg?branch=develop)](https://github.com/podaac/concise/actions/workflows/build-pipeline.yml)  
main: [![Main Build](https://github.com/podaac/concise/actions/workflows/build-pipeline.yml/badge.svg?branch=main&event=push)](https://github.com/podaac/concise/actions/workflows/build-pipeline.yml)


Harmony service for concatenating L2 data.

If you would like to contribute to Concise, refer to the [contribution document](CONTRIBUTING.md).

## How to test Concise locally

There are comprehensive unit tests for Concise. The tests can be run as follows:

```shell script
poetry run pytest tests/
```

